==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/shells/generic/iggdialogauto.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Automatically shown dialog
//

#ifndef IGGDIALOGAUTO_H
#define IGGDIALOGAUTO_H


#include "iggdialog.h"


#include "istring.h"


class iggDialogAuto : public iggDialog
{

	friend class iggMainWindow;

public:

	virtual ~iggDialogAuto();

	const iString& GetTitle() const { return mTitle; }
	virtual void Show(bool s);
	void ForceShow(bool s);

protected:

	iggDialogAuto(iggMainWindow *mw, const iString &title, int cols);

private:

	const iString mTitle;
	static bool mBlockShowing;
};

#endif  // IGGDIALOGAUTO_H

==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/generic/iggdialogauto.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Automatically shown dialog
//

#ifndef IGGDIALOGAUTO_H
#define IGGDIALOGAUTO_H


#include "iggdialog.h"


#include "istring.h"


class iggDialogAuto : public iggDialog
{

	friend class iggMainWindow;

public:

	virtual ~iggDialogAuto();

	const iString& GetTitle() const { return mTitle; }
	void ForceShow(bool s);

protected:

	iggDialogAuto(iggMainWindow *mw, const iString &title, int cols);

	virtual void ShowBody(bool s);

private:

	const iString mTitle;
	static bool mBlockShowing;
};

#endif  // IGGDIALOGAUTO_H
